
/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "antConfigPage.h"
#include "RulerConfigPage.h"
#include "antConfig.h"

namespace ant
{

// ------------------------------------------------------------
//  Implementation of the configuration page

ConfigPage::ConfigPage (QWidget *parent)
  : lay::ConfigPage (parent)
{
  mp_ui = new Ui::RulerConfigPage ();
  mp_ui->setupUi (this);

  mp_ruler_color_cbtn = new lay::ColorButton (mp_ui->ruler_color_pb);
}

ConfigPage::~ConfigPage ()
{
  delete mp_ui;
  mp_ui = 0;
}

void 
ConfigPage::setup (lay::Plugin *root)
{
  std::string value;

  //  Max. number of rulers
  int max_number_of_rulers = -1;
  root->config_get (cfg_max_number_of_rulers, max_number_of_rulers);
  if (max_number_of_rulers < 0) {
    mp_ui->num_rulers_edit->setText ("");
  } else {
    mp_ui->num_rulers_edit->setText (tl::to_string (max_number_of_rulers).c_str ());
  }

  //  Snap range
  int snap_range = 0;
  root->config_get (cfg_ruler_snap_range, snap_range);
  mp_ui->ruler_snap_range_edit->setText (tl::to_string (snap_range).c_str ());

  //  color
  QColor color;
  root->config_get (cfg_ruler_color, color, lay::ColorConverter ());
  mp_ruler_color_cbtn->set_color (color);

  //  object and grid snap
  bool f = false;
  root->config_get (cfg_ruler_obj_snap, f);
  mp_ui->ruler_obj_snap_cbx->setChecked (f);
  root->config_get (cfg_ruler_grid_snap, f);
  mp_ui->ruler_grid_snap_cbx->setChecked (f);

  //  snap mode
  ant::Service::SnapMode rm = ant::Service::Any;
  root->config_get (cfg_ruler_snap_mode, rm, SnapModeConverter ());
  mp_ui->ruler_any_angle_rb->setChecked (rm == ant::Service::Any);
  mp_ui->ruler_ortho_rb->setChecked (rm == ant::Service::Ortho);
  mp_ui->ruler_diag_rb->setChecked (rm == ant::Service::Diagonal);
  mp_ui->ruler_hor_rb->setChecked (rm == ant::Service::Horizontal);
  mp_ui->ruler_vert_rb->setChecked (rm == ant::Service::Vertical);
}

void 
ConfigPage::commit (lay::Plugin *root)
{
  int sr = 0;
  tl::from_string (mp_ui->ruler_snap_range_edit->text ().ascii (), sr);
  if (sr < 1 || sr > 1000) {
    throw tl::Exception (tl::translate ("Not a valid pixel value (must be non-zero positive and not too large): %s").c_str (), mp_ui->ruler_snap_range_edit->text ().ascii ());
  }
  root->config_set (cfg_ruler_snap_range, sr);

  int mr;
  try {
    tl::from_string (mp_ui->num_rulers_edit->text ().ascii (), mr);
  } catch (...) {
    mr = -1;
  }
  root->config_set (cfg_max_number_of_rulers, mr);

  root->config_set (cfg_ruler_color, mp_ruler_color_cbtn->get_color (), lay::ColorConverter ());
  root->config_set (cfg_ruler_obj_snap, mp_ui->ruler_obj_snap_cbx->isChecked ());
  root->config_set (cfg_ruler_grid_snap, mp_ui->ruler_grid_snap_cbx->isChecked ());

  ant::Service::SnapMode rm = ant::Service::Any;
  if (mp_ui->ruler_any_angle_rb->isChecked ()) {
    rm = ant::Service::Any;
  }
  if (mp_ui->ruler_ortho_rb->isChecked ()) {
    rm = ant::Service::Ortho;
  }
  if (mp_ui->ruler_diag_rb->isChecked ()) {
    rm = ant::Service::Diagonal;
  }
  if (mp_ui->ruler_hor_rb->isChecked ()) {
    rm = ant::Service::Horizontal;
  }
  if (mp_ui->ruler_vert_rb->isChecked ()) {
    rm = ant::Service::Vertical;
  }
  root->config_set (cfg_ruler_snap_mode, rm, SnapModeConverter ());
}


} // namespace ant
