
/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "layPlugin.h"
#include "antConfigPage.h"
#include "antConfig.h"

namespace ant
{

class PluginDeclaration
  : public lay::PluginDeclaration
{
public:
  virtual void get_options (std::vector < std::pair<std::string, std::string> > &options) const
  {
    options.push_back (std::pair<std::string, std::string> (cfg_max_number_of_rulers, "-1"));
    options.push_back (std::pair<std::string, std::string> (cfg_ruler_snap_range, "8"));
    options.push_back (std::pair<std::string, std::string> (cfg_ruler_color, lay::ColorConverter ().to_string (QColor ())));
    options.push_back (std::pair<std::string, std::string> (cfg_ruler_snap_mode, SnapModeConverter ().to_string (ant::Service::Any)));
    options.push_back (std::pair<std::string, std::string> (cfg_ruler_obj_snap, tl::to_string (true)));
    options.push_back (std::pair<std::string, std::string> (cfg_ruler_grid_snap, tl::to_string (false)));
    //  grid-micron is not configured here since some other entity is supposed to do this.
  }

  virtual lay::ConfigPage *config_page (QWidget *parent, std::string &title) const
  {
    title = tl::translate ("Rulers");
    return new ant::ConfigPage (parent); 
  }

  virtual void get_menu_entries (std::vector<lay::MenuEntry> &menu_entries) const
  {
    lay::PluginDeclaration::get_menu_entries (menu_entries);
    menu_entries.push_back (lay::MenuEntry ("ant::clear_all_rulers", "edit.last", tl::translate ("Clear all rulers")));
  }

  virtual lay::Plugin *create_plugin (db::Manager *manager, lay::MainWindow *, lay::LayoutView *view) const
  {
    return new ant::Service (manager, view);
  }

  virtual bool implements_editable (std::string &title) const
  {
    title = tl::translate ("Ruler");
    return true;
  }
  
  virtual bool implements_mouse_mode (std::string &title) const
  {
    title = tl::translate ("Ruler") + "<:ruler.png>";
    return true;
  }
};

static tl::Registrar<lay::PluginDeclaration>::Class config_decl (new ant::PluginDeclaration (), 3000, "ant::Plugin");

}

