
/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "dbReader.h"
#include "dbOASISReader.h"
#include "dbGDS2Reader.h"

namespace db
{

// ---------------------------------------------------------------
//  Reader implementation

Reader::Reader (db::Stream &stream)
  : mp_actual_reader (0)
{
  const char *hdr = stream.get (4);
  stream.unget (4);

  if (hdr && hdr[0] == 0x25 && hdr[1] == 0x53 && hdr[2] == 0x45 && hdr[3] == 0x4d) {

    //  OASIS
    mp_actual_reader = new db::OASISReader (stream);

  } else if (hdr && hdr[0] == 0x00 && hdr[1] == 0x06 && hdr[2] == 0x00 && hdr[3] == 0x02) {

    //  GDS2
    mp_actual_reader = new db::GDS2Reader (stream);

  } else {
    throw db::ReaderException (tl::translate ("Stream has unknown format"));
  }
}

Reader::~Reader ()
{
  if (mp_actual_reader) {
    delete mp_actual_reader;
    mp_actual_reader = 0;
  }
}

}

