
/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "layPlugin.h"
#include "edtService.h"
#include "edtInstService.h"

namespace edt
{

class ShapePluginDeclaration
  : public lay::PluginDeclaration
{
public:
  ShapePluginDeclaration (const std::string &title, db::ShapeIterator::flags_type flags)
    : m_title (title), m_flags (flags)
  {
    //  .. nothing yet ..
  }

  virtual void get_options (std::vector < std::pair<std::string, std::string> > &options) const
  {
    //  .. nothing yet ..
  }

  virtual lay::ConfigPage *config_page (QWidget *parent, std::string &title) const
  {
    return 0;
  }

  virtual void get_menu_entries (std::vector<lay::MenuEntry> &menu_entries) const
  {
    //  .. nothing yet ..
  }

  virtual lay::Plugin *create_plugin (db::Manager *manager, lay::MainWindow *, lay::LayoutView *view) const
  {
    return new edt::Service (manager, view, m_flags);
  }

  virtual bool implements_editable (std::string &title) const
  {
    title = m_title;
    return true;
  }
  
  virtual bool implements_mouse_mode (std::string &title) const
  {
    return false;
  }

private:
  std::string m_title;
  db::ShapeIterator::flags_type m_flags;
};

static tl::Registrar<lay::PluginDeclaration>::Class config_decl1 (new edt::ShapePluginDeclaration (tl::translate ("Polygons"), db::ShapeIterator::Polygons), 4000, "edt::Service(Polygons)");
static tl::Registrar<lay::PluginDeclaration>::Class config_decl2 (new edt::ShapePluginDeclaration (tl::translate ("Boxes"), db::ShapeIterator::Boxes), 4001, "edt::Service(Boxes)");
static tl::Registrar<lay::PluginDeclaration>::Class config_decl4 (new edt::ShapePluginDeclaration (tl::translate ("Texts"), db::ShapeIterator::Texts), 4002, "edt::Service(Texts)");
static tl::Registrar<lay::PluginDeclaration>::Class config_decl3 (new edt::ShapePluginDeclaration (tl::translate ("Paths"), db::ShapeIterator::Paths), 4003, "edt::Service(Paths)");

class InstPluginDeclaration
  : public lay::PluginDeclaration
{
public:
  InstPluginDeclaration (const std::string &title)
    : m_title (title)
  {
    //  .. nothing yet ..
  }

  virtual void get_options (std::vector < std::pair<std::string, std::string> > &options) const
  {
    //  .. nothing yet ..
  }

  virtual lay::ConfigPage *config_page (QWidget *parent, std::string &title) const
  {
    return 0;
  }

  virtual void get_menu_entries (std::vector<lay::MenuEntry> &menu_entries) const
  {
    //  .. nothing yet ..
  }

  virtual lay::Plugin *create_plugin (db::Manager *manager, lay::MainWindow *, lay::LayoutView *view) const
  {
    return new edt::InstService (manager, view);
  }

  virtual bool implements_editable (std::string &title) const
  {
    title = m_title;
    return true;
  }
  
  virtual bool implements_mouse_mode (std::string &title) const
  {
    return false;
  }

private:
  std::string m_title;
};

static tl::Registrar<lay::PluginDeclaration>::Class config_decl10 (new edt::InstPluginDeclaration (tl::translate ("Instances")), 4010, "edt::InstService");
}

