
/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_layLayout
#define HDR_layLayout

#include "layProxy.h"
#include "layDrawing.h"

#include <list>



/// Layout object:
/// Representing the layout "document". Issues other objects
/// representing different proxies to the actual database below
/// the layout object. The database itself is only accessible 
/// through the proxies. This way, the dependencies and drawing
/// update issues are resolved.

class lay::ToScreen;
class lay::Layers;
class lay::Options;

class lay::Layout
{
public:
  /// constructor (mainly for the database)
  Layout ();

  /// start the drawing process using the layer properties
  /// provided and drawing the layer list in the order the
  /// layers appear there. 
  lay::DrawingProxy draw (int w, int h, 
                          const lay::ToScreen &transform, 
                          const lay::Layers &layers,
                          const lay::Options &options);

  /// get a proxy to the database. As long as a proxy
  /// exists, drawing is stopped. It will continue and be
  /// restarted if the database has been changed.
  lay::DbProxy db ();

  /// unregister callback of a proxy object
  void operator() (lay::DbProxy &db_proxy, size_t left);
  void operator() (lay::DrawProxy &db_proxy, size_t left);
  
private:
  lay::ProxyList <lay::Layout, lay::DbProxy> m_db_proxies;
  lay::ProxyList <lay::Layout, lay::DrawProxy, lay::Drawing> m_draw_proxies;

};

#endif


