
/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_layProgress
#define HDR_layProgress

#include <string>
#include <list>

#include <QtGui/QFrame>

#include "tlProgress.h"
#include "tlTimer.h"

class QToolButton;
class QApplication;
class QLabel;
class QToolButton;

namespace lay
{

class ProgressReporter;
class StatusBar;

class ProgressBar;

class ProgressWidget
  : public QFrame
{
Q_OBJECT

public:
  ProgressWidget (ProgressReporter *pr, QWidget *parent, const char *name = "");

  void set_text (const std::string &text);
  void set_value (double v, const std::string &value);

public slots:
  void signal_break ();

private:
  QLabel *mp_label;
  ProgressBar *mp_progress_bar;
  QToolButton *mp_cancel_button;
  ProgressReporter *mp_pr;
};

class ProgressReporter 
  : public tl::ProgressAdaptor
{
public:
  ProgressReporter (lay::StatusBar *sb, QApplication *app);
  virtual ~ProgressReporter ();

  virtual void register_object (tl::Progress *progress);
  virtual void unregister_object (tl::Progress *progress);
  virtual void trigger (tl::Progress *progress);
  virtual void yield (tl::Progress *progress);

  void signal_break ();

private:
  std::list <tl::Progress *> mp_objects;
  QApplication *mp_app;
  tl::Clock m_start_time;
  lay::StatusBar *mp_sb;
  bool m_pw_visible;

  void processEvents ();
};

}

#endif

