
/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#ifndef HDR_layViewOp
#define HDR_layViewOp

#include <inttypes.h>

namespace lay
{

typedef unsigned int color_t; 

const unsigned int wordlen  = 32;
const unsigned int wordbits = 5;
const unsigned int wordones = 0xffffffff;

class ViewOp
{
public:
  enum Mode { Copy, Or, And, Xor };
  enum Shape { Rect, Cross };

private:
  color_t m_or;
  color_t m_and;
  color_t m_xor;
  unsigned int m_dither_index;
  Shape m_shape;
  int m_width;

  void init (color_t color, Mode mode);

public:
  ViewOp ();
  ViewOp (color_t color, Mode mode = Copy, unsigned int dither_index = 0, Shape shape = Rect, int width = 1);
  
  color_t ormask () const
  { 
    return m_or; 
  }

  color_t andmask () const
  { 
    return m_and; 
  }

  color_t xormask () const
  { 
    return m_xor; 
  }

  Shape shape () const
  {
    return m_shape;
  }

  int width () const
  {
    return m_width;
  }

  void dither_index (unsigned int di) 
  {
    m_dither_index = di;
  }

  unsigned int dither_index () const
  {
    return m_dither_index;
  }

  bool operator== (const ViewOp &d) const
  {
    return (m_or == d.m_or && m_and == d.m_and && 
            m_xor == d.m_xor && m_dither_index == d.m_dither_index &&
            m_width == d.m_width && m_shape == d.m_shape);
  }
  
  bool operator< (const ViewOp &d) const
  {
    if (m_or != d.m_or) return (m_or < d.m_or);
    if (m_and != d.m_and) return m_and < d.m_and;
    if (m_xor != d.m_xor) return m_xor < d.m_xor;
    if (m_dither_index != d.m_dither_index) return m_dither_index < d.m_dither_index;
    if (m_width != d.m_width) return m_width < d.m_width;
    if (m_shape != d.m_shape) return m_shape < d.m_shape;
    return false;
  }
};

} // namespace lay

#endif

