
/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include <dbLayout.h>
#include <dbOASISReader.h>
#include <dbGDS2Writer.h>

int 
main (int argc, char *argv [])
{
  if (argc != 3) {
    printf ("Syntax: oas2gds <infile.oas> <outfile.gds>\n");
    return 1;
  }

  std::string infile (argv[1]);
  std::string outfile (argv[2]);

  try {

    db::Manager m;
    db::Layout layout (&m);
    db::FileStream stream;
    db::OASISReader reader (stream);

    stream.open (infile.c_str ());
    db::LayerMap map = reader.read (layout);
    stream.close ();

    db::FileStream output;
    db::GDS2Writer writer (output);
    output.open (outfile.c_str (), false /*=writing*/);
    writer.write (layout);
    output.close ();

  } catch (std::exception &ex) {
    fprintf (stderr, "*** ERROR: %s\n", ex.what ());
    return 1;
  } catch (tl::Exception &ex) {
    fprintf (stderr, "*** ERROR: %s\n", ex.msg ().c_str ());
    return 1;
  } catch (...) {
    fprintf (stderr, "*** ERROR: unspecific error\n");
    return 1;
  }

  return 0;
}


