
/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include <tlObserver.h>

namespace tl
{

// --------------------------------------------------------------------
//  Observer implementation

Observer::Observer ()
  : m_observed (0)
{ 
  // .. nothing yet ..
}

Observer::~Observer ()
{
  if (m_observed) {
    Observed *o = m_observed;
    m_observed = 0;
    o->remove_observer (*this);
  }
}

void 
Observer::observer_attach (Observed *observed, std::list<Observer *>::iterator ptr)
{
  m_ptr = ptr;
  m_observed = observed;
}

void 
Observer::signal_observed () 
{
  //  base implementation does nothing
}

void 
Observer::signal_observed_int (int) 
{
  //  base implementation does nothing
}

void 
Observer::signal_observed_voidp (void *) 
{
  //  base implementation does nothing
}

bool 
Observer::observes () const 
{
  return m_observed != 0;
}

// --------------------------------------------------------------------
//  Observed implementation

Observed::~Observed ()
{
  while (m_observers.begin () != m_observers.end ()) {
    remove_observer (*m_observers.front ());
  }
}

void 
Observed::add_observer (Observer &observer)
{
  if (observer.observed ()) {
    observer.observed ()->remove_observer (observer);
  }
  observer.observer_attach (this, m_observers.insert (m_observers.end (), & observer));
}

void 
Observed::remove_observer (Observer &observer)
{
  m_observers.erase (observer.ptr ());
  observer.observer_attach (0, m_observers.end ());
}

void 
Observed::signal_observers () const
{
  for (std::list<Observer *>::const_iterator o = m_observers.begin (); o != m_observers.end (); ++o) {
    (*o)->signal_observed ();
  }
}

void 
Observed::signal_observers (int arg) const
{
  for (std::list<Observer *>::const_iterator o = m_observers.begin (); o != m_observers.end (); ++o) {
    (*o)->signal_observed_int (arg);
  }
}

void 
Observed::signal_observers (void *arg) const
{
  for (std::list<Observer *>::const_iterator o = m_observers.begin (); o != m_observers.end (); ++o) {
    (*o)->signal_observed_voidp (arg);
  }
}

size_t 
Observed::observers () const 
{
  return m_observers.size ();
}

} // namespace tl


